#ifndef _RJTE_H_
#define _RJTE_H_

#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <avr/signal.h>

#include "rjte_int.h"

/* LEDs - set to ON or OFF */
#define LED1		IO_BITS(0x32).bit_5
#define LED2		IO_BITS(0x32).bit_6
#define LED3		IO_BITS(0x32).bit_7

/* These definitions make code more readable for active low I/O.
 *
 * The LEDs are connected between the I/O pin and Vcc, so 0 turns them on.
 * Buttons are connected to GND with a pull-up in the chip.  Pressing the
 * button makes the pin go low.
 */
#define ON		0
#define OFF		1

/* Motor directions */
#define FORWARD		0
#define REVERSE		1

/* Debounced button states */
#define BUTTON1		(button_states & 1)
#define BUTTON2		(button_states & 2)

/* Where the debounced button states are actually stored.
 * Button states are bits in this variable.
 * Use BUTTON1 and BUTTON2 to get the bits.
 *
 * You can use this variable to quickly find changes in button
 * states using boolean operators.
 *
 * Don't ever change the value of this variable.  It gets set
 * frequently by an interrupt handler.
 */
extern volatile u8 button_states;

/* Call this only once as the first thing in main() */
void initialize();

/* These set the motor speeds and directions.
 *
 * Use FORWARD and REVERSE for direction.
 */
void setMotorA(u8 speed, u8 direction);
void setMotorB(u8 speed, u8 direction);

#endif /* _RJTE_H_ */

